@@ -315,3 +315,7 @@ class Context:
     @property
     def filename(self):
         return self._context.get("filename")
+
+    @property
+    def file_data(self):
+        return self._context.get("file_data")
