@@ -1,10 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
 # SPDX-License-Identifier: Apache-2.0
-
-
 import collections
 import logging
 
@@ -12,7 +9,7 @@ import logging
 LOG = logging.getLogger(__name__)
 
 
-class BanditMetaAst(object):
+class BanditMetaAst:
 
     nodes = collections.OrderedDict()
 
@@ -20,25 +17,27 @@ class BanditMetaAst(object):
         pass
 
     def add_node(self, node, parent_id, depth):
-        '''Add a node to the AST node collection
+        """Add a node to the AST node collection
 
         :param node: The AST node to add
         :param parent_id: The ID of the node's parent
         :param depth: The depth of the node
         :return: -
-        '''
+        """
         node_id = hex(id(node))
-        LOG.debug('adding node : %s [%s]', node_id, depth)
+        LOG.debug("adding node : %s [%s]", node_id, depth)
         self.nodes[node_id] = {
-            'raw': node, 'parent_id': parent_id, 'depth': depth
+            "raw": node,
+            "parent_id": parent_id,
+            "depth": depth,
         }
 
     def __str__(self):
-        '''Dumps a listing of all of the nodes
+        """Dumps a listing of all of the nodes
 
         Dumps a listing of all of the nodes for debugging purposes
         :return: -
-        '''
+        """
         tmpstr = ""
         for k, v in self.nodes.items():
             tmpstr += "Node: %s\n" % k
