@@ -24,6 +24,12 @@ This formatter outputs the issues as plain text.
 
 .. versionadded:: 0.9.0
 
+.. versionchanged:: 1.5.0
+    New field `more_info` added to output
+
+.. versionchanged:: 1.7.3
+    New field `CWE` added to output
+
 """
 import datetime
 import logging
@@ -80,9 +86,15 @@ def _output_issue_str(
 
     bits.append(
         "%s   Severity: %s   Confidence: %s"
-        % (indent, issue.severity.capitalize(), issue.confidence.capitalize())
+        % (
+            indent,
+            issue.severity.capitalize(),
+            issue.confidence.capitalize(),
+        )
     )
 
+    bits.append(f"{indent}   CWE: {str(issue.cwe)}")
+
     bits.append(
         "%s   Location: %s:%s:%s"
         % (
@@ -166,6 +178,11 @@ def report(manager, fileobj, sev_level, conf_level, lines=-1):
             "\tTotal lines skipped (#nosec): %i"
             % (manager.metrics.data["_totals"]["nosec"])
         )
+        bits.append(
+            "\tTotal potential issues skipped due to specifically being "
+            "disabled (e.g., #nosec BXXX): %i"
+            % (manager.metrics.data["_totals"]["skipped_tests"])
+        )
 
         skipped = manager.get_skipped()
         bits.append(get_metrics(manager))
