@@ -16,6 +16,7 @@ Python docs succinctly describe why the use of `exec` is risky.
 
     >> Issue: Use of exec detected.
        Severity: Medium   Confidence: High
+       CWE: CWE-78 (https://cwe.mitre.org/data/definitions/78.html)
        Location: ./examples/exec.py:2
     1 exec("do evil")
     2 exec "do evil"
@@ -26,10 +27,16 @@ Python docs succinctly describe why the use of `exec` is risky.
  - https://docs.python.org/3/library/functions.html#exec
  - https://www.python.org/dev/peps/pep-0551/#background
  - https://www.python.org/dev/peps/pep-0578/#suggested-audit-hook-locations
+ - https://cwe.mitre.org/data/definitions/78.html
 
 .. versionadded:: 0.9.0
+
+.. versionchanged:: 1.7.3
+    CWE information added
+
 """
 import bandit
+from bandit.core import issue
 from bandit.core import test_properties as test
 
 
@@ -37,6 +44,7 @@ def exec_issue():
     return bandit.Issue(
         severity=bandit.MEDIUM,
         confidence=bandit.HIGH,
+        cwe=issue.Cwe.OS_COMMAND_INJECTION,
         text="Use of exec detected.",
     )
 
